@@ -19,3 +19,8 @@ pub const PROGRAMMER_START_CONFIG_UPGRADE_EVENT_CODE: u16 = 0x000a;
 pub const PROGRAMMER_SET_DEVICE_ADDRESS_EVENT_CODE: u16 = 0x000b;
 
 pub const MESSAGE_EVENT_CODE: u16 = 0x000c;
+
+pub const BCM_ANIMATE_BRIGHTNESS_EVENT_CODE: u16 = 0x000d;
+
+pub const RELAY_SET_STATE_EVENT_CODE: u16 = 0x000e;
+pub const RELAY_FLIP_STATE_EVENT_CODE: u16 = 0x000f;
